/**
*   Please feel free to use any fragment of the code in this file that you need
*   in your own work. As far as I am concerned, it's in the public domain. No
*   permission is necessary or required. Credit is always appreciated if you
*   use a large chunk or base a significant product on one of my examples,
*   but that's not required either.
*
*   This code is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty of
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*
*      --- Joseph A. Huwaldt
**/

import jahuwaldt.tools.ParamTools.*;


/**
*  Calculates total pressure ratio at the surface of the
*  cone from the free stream Mach number and conical shock angle.
*
*  <p>  Modified by:  Joseph A. Huwaldt   </p>
*
*  @author   Joseph A. Huwaldt  Date: November 2, 2004
*  @version  November 7, 2004
**/
public class PT_PMethod extends ParamMethod implements SharedData {
	
	/**
	*  Constructor for this method.
	*
	*  @param   Mach    Label for the "free-stream Mach number" parameter.
	*  @param   thetaS  Label for the "shock angle" parameter.
	**/
	public PT_PMethod(String Mach, String thetaS) {
		inputLabels = new String[2];
		inputLabels[0] = Mach;
		inputLabels[1] = thetaS;
	}
	
	
	/**
	*  Calculates total pressure ratio at the surface of the
	*  cone from the free stream Mach number and conical shock angle.
	*
	*  @param   inputs  Array of input parameters.
	*                   [0=free-stream Mach number (Mach), 1=oblique shock angle (thetaS)].
	*  @return  Total pressure ratio (PT/P) at surface of cone.
	**/
	public float calc(float[] inputs) throws Exception {
		float Mach = inputs[0];
		float thetaS = inputs[1];
		
		float result = (float)conicalShock.conePT_P(Mach, thetaS);
		
		return result;
	}

}
