/*
*   CannotConvertException - Exception thrown when trying to convert incompatible units.
*
*   Copyright (C) 1997-2004 by Joseph A. Huwaldt
*   All rights reserved.
*   
*   This library is free software; you can redistribute it and/or
*   modify it under the terms of the GNU Lesser General Public
*   License as published by the Free Software Foundation; either
*   version 2 of the License, or (at your option) any later version.
*   
*   This library is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty of
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*   Library General Public License for more details.
*
*   You should have received a copy of the GNU Lesser General Public License
*   along with this program; if not, write to the Free Software
*   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*   Or visit:  http://www.gnu.org/licenses/lgpl.html
**/
package jahuwaldt.tools.units;


/**
*  Unit routines may throw this exception if the user attempts to
*  convert incompatable units (such as converting Meters to Seconds).
*
*  <p>  Modified by:  Joseph A. Huwaldt  </p>
*
*  @author  Joseph A. Huwaldt   Date: December 17, 1997
*  @version July 25, 2004
**/
public class CannotConvertException extends Exception {

	/**
	*  Constructs a CannotConvertException with no detailed message.
	*  A detail message is a String that describes this particular exception.
	**/
	public CannotConvertException() { }

	/**
	*  Constructs a CannotConvertException with the specified detail message.
	*  A detail message is a String that describes this particular exception.
	*
	*	@param msg  The String containing a detail message.
	**/
	public CannotConvertException( String msg ) {
		super( msg );
	}

	/**
	* Returns a short description of the CannotConvertException.
	*
	*	@return  A short description of the Exception as a String.
	**/
	public String toString() {
		return getMessage();
	}

}


