/*
*   Radians - Angular unit "radians".
*
*   Copyright (C) 1997-2004 by Joseph A. Huwaldt
*   All rights reserved.
*   
*   This library is free software; you can redistribute it and/or
*   modify it under the terms of the GNU Lesser General Public
*   License as published by the Free Software Foundation; either
*   version 2 of the License, or (at your option) any later version.
*   
*   This library is distributed in the hope that it will be useful,
*   but WITHOUT ANY WARRANTY; without even the implied warranty of
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
*   Library General Public License for more details.
*
*   You should have received a copy of the GNU Lesser General Public License
*   along with this program; if not, write to the Free Software
*   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*   Or visit:  http://www.gnu.org/licenses/lgpl.html
**/
package jahuwaldt.tools.units;


/**
*  <p>  The angular unit: radians.
*       This is the reference unit for the AngularUnit type.
*  </p>
*
*  <p>  Modified by:  Joseph A. Huwaldt  </p>
*
*  @author   Joseph A. Huwaldt   Date: December 18, 1997
*  @version  November 6, 2004
**/
public final class Radians extends AngularUnit {

	private static Radians example = new Radians();

	private Radians() {
		name = "radians";
		abv = "rad";
		exact = true;
	}

	static final double theFactor = 1.0;

	/**
	*  Returns the number of radians in a radian.
	**/
	protected double factor() {
		return theFactor;
	}

	/**
	*	Return a reference to the one and only instance of this class.
	**/
	public static Radians getInstance() {
		return example;
	}


}


